@@ -24,8 +24,7 @@ use AsyncAws\Ses\ValueObject\Template;
 final class SendEmailRequest extends Input
 {
     /**
-     * The email address that you want to use as the "From" address for the email. The address that you specify has to be
-     * verified.
+     * The email address to use as the "From" address for the email. The address that you specify has to be verified.
      *
      * @var string|null
      */
@@ -89,7 +88,7 @@ final class SendEmailRequest extends Input
     private $emailTags;
 
     /**
-     * The name of the configuration set that you want to use when sending the email.
+     * The name of the configuration set to use when sending the email.
      *
      * @var string|null
      */
@@ -210,7 +209,7 @@ final class SendEmailRequest extends Input
 
         // Prepare Body
         $bodyPayload = $this->requestBody();
-        $body = empty($bodyPayload) ? '{}' : json_encode($bodyPayload);
+        $body = empty($bodyPayload) ? '{}' : json_encode($bodyPayload, 4194304);
 
         // Return the Request
         return new Request('POST', $uriString, $query, $headers, StreamFactory::create($body));
